////////////////////////////////////////////////////////////////////////////
//
// Copyright 2014-2015 Realm Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
////////////////////////////////////////////////////////////////////////////

@import Cocoa;
@import Realm;

#import "RLMRealmNode.h"

typedef NS_ENUM(NSInteger, RLMDocumentState) {
    RLMDocumentStateRequiresFormatUpgrade,
    RLMDocumentStateNeedsEncryptionKey,
    RLMDocumentStateNeedsValidCredential,
    RLMDocumentStateLoadingSchema,
    RLMDocumentStateLoaded,
    RLMDocumentStateUnrecoverableError
};

@interface RLMDocument : NSDocument

@property (nonatomic, assign) RLMDocumentState state;
@property (nonatomic, strong) IBOutlet RLMRealmNode *presentedRealm;

@property (nonatomic, copy, readonly) NSURL *syncURL;
@property (nonatomic, copy, readonly) NSURL *authServerURL;
@property (nonatomic, strong, readonly) RLMSyncCredential *credential;

- (instancetype)initWithContentsOfFileURL:(NSURL *)fileURL error:(NSError **)outError;
- (instancetype)initWithContentsOfSyncURL:(NSURL *)syncURL credential:(RLMSyncCredential *)credential authServerURL:(NSURL *)authServerURL error:(NSError **)outError;

- (BOOL)loadByPerformingFormatUpgradeWithError:(NSError * __autoreleasing *)error;
- (BOOL)loadWithEncryptionKey:(NSData *)key error:(NSError * __autoreleasing *)error;
- (void)loadWithCredential:(RLMSyncCredential *)credential completionHandler:(void (^)(NSError *error))completionHandler;

@end
